==> zio-aws-pinpointemail_2.12-5.17.151.2-sources.jar: zio/aws/pinpointemail/model/BlacklistEntry.scala <==
package zio.aws.pinpointemail.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.pinpointemail.model.primitives.{
  BlacklistingDescription,
  Timestamp,
  RblName
}
import java.time.Instant
import scala.jdk.CollectionConverters._
final case class BlacklistEntry(
    rblName: Option[RblName] = None,
    listingTime: Option[Timestamp] = None,
    description: Option[BlacklistingDescription] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpointemail.model.BlacklistEntry = {
    import BlacklistEntry.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpointemail.model.BlacklistEntry
      .builder()
      .optionallyWith(
        rblName.map(value => RblName.unwrap(value): java.lang.String)
      )(_.rblName)
      .optionallyWith(
        listingTime.map(value => Timestamp.unwrap(value): Instant)
      )(_.listingTime)
      .optionallyWith(
        description.map(value =>
          BlacklistingDescription.unwrap(value): java.lang.String
        )
      )(_.description)
      .build()
  }
  def asReadOnly: zio.aws.pinpointemail.model.BlacklistEntry.ReadOnly =
    zio.aws.pinpointemail.model.BlacklistEntry.wrap(buildAwsValue())
}
object BlacklistEntry {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpointemail.model.BlacklistEntry
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpointemail.model.BlacklistEntry =
      zio.aws.pinpointemail.model.BlacklistEntry(
        rblName.map(value => value),
        listingTime.map(value => value),
        description.map(value => value)
      )
    def rblName: Option[RblName]
    def listingTime: Option[Timestamp]
    def description: Option[BlacklistingDescription]
    def getRblName: ZIO[Any, AwsError, RblName] =
      AwsError.unwrapOptionField("rblName", rblName)
    def getListingTime: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("listingTime", listingTime)
    def getDescription: ZIO[Any, AwsError, BlacklistingDescription] =
      AwsError.unwrapOptionField("description", description)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpointemail.model.BlacklistEntry
  ) extends zio.aws.pinpointemail.model.BlacklistEntry.ReadOnly {
    override val rblName: Option[RblName] = scala
      .Option(impl.rblName())
      .map(value => zio.aws.pinpointemail.model.primitives.RblName(value))
    override val listingTime: Option[Timestamp] = scala
      .Option(impl.listingTime())
      .map(value => zio.aws.pinpointemail.model.primitives.Timestamp(value))
    override val description: Option[BlacklistingDescription] = scala
      .Option(impl.description())
      .map(value =>
        zio.aws.pinpointemail.model.primitives.BlacklistingDescription(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpointemail.model.BlacklistEntry
  ): zio.aws.pinpointemail.model.BlacklistEntry.ReadOnly = new Wrapper(impl)
}

==> zio-aws-pinpointemail_2.12-5.19.8.3-sources.jar: zio/aws/pinpointemail/model/BlacklistEntry.scala <==
package zio.aws.pinpointemail.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.pinpointemail.model.primitives.{
  BlacklistingDescription,
  Timestamp,
  RblName
}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import scala.jdk.CollectionConverters._
final case class BlacklistEntry(
    rblName: Optional[RblName] = Optional.Absent,
    listingTime: Optional[Timestamp] = Optional.Absent,
    description: Optional[BlacklistingDescription] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpointemail.model.BlacklistEntry = {
    import BlacklistEntry.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpointemail.model.BlacklistEntry
      .builder()
      .optionallyWith(
        rblName.map(value => RblName.unwrap(value): java.lang.String)
      )(_.rblName)
      .optionallyWith(
        listingTime.map(value => Timestamp.unwrap(value): Instant)
      )(_.listingTime)
      .optionallyWith(
        description.map(value =>
          BlacklistingDescription.unwrap(value): java.lang.String
        )
      )(_.description)
      .build()
  }
  def asReadOnly: zio.aws.pinpointemail.model.BlacklistEntry.ReadOnly =
    zio.aws.pinpointemail.model.BlacklistEntry.wrap(buildAwsValue())
}
object BlacklistEntry {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpointemail.model.BlacklistEntry
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpointemail.model.BlacklistEntry =
      zio.aws.pinpointemail.model.BlacklistEntry(
        rblName.map(value => value),
        listingTime.map(value => value),
        description.map(value => value)
      )
    def rblName: Optional[RblName]
    def listingTime: Optional[Timestamp]
    def description: Optional[BlacklistingDescription]
    def getRblName: ZIO[Any, AwsError, RblName] =
      AwsError.unwrapOptionField("rblName", rblName)
    def getListingTime: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("listingTime", listingTime)
    def getDescription: ZIO[Any, AwsError, BlacklistingDescription] =
      AwsError.unwrapOptionField("description", description)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpointemail.model.BlacklistEntry
  ) extends zio.aws.pinpointemail.model.BlacklistEntry.ReadOnly {
    override val rblName: Optional[RblName] = zio.aws.core.internal
      .optionalFromNullable(impl.rblName())
      .map(value => zio.aws.pinpointemail.model.primitives.RblName(value))
    override val listingTime: Optional[Timestamp] = zio.aws.core.internal
      .optionalFromNullable(impl.listingTime())
      .map(value => zio.aws.pinpointemail.model.primitives.Timestamp(value))
    override val description: Optional[BlacklistingDescription] =
      zio.aws.core.internal
        .optionalFromNullable(impl.description())
        .map(value =>
          zio.aws.pinpointemail.model.primitives.BlacklistingDescription(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpointemail.model.BlacklistEntry
  ): zio.aws.pinpointemail.model.BlacklistEntry.ReadOnly = new Wrapper(impl)
}
